@@ -1,5 +1,5 @@
-# $Date: 2007-06-03 21:39:50 -0700 (Sun, 03 Jun 2007) $
-# $Revision: 92 $
+# $Date: 2007-06-07 22:28:00 -0700 (Thu, 07 Jun 2007) $
+# $Revision: 101 $
 # $Author: david.romano $
 # ex: set ts=8 sw=4 et
 #########################################################################
@@ -9,7 +9,7 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.3.2');
+use version; our $VERSION = qv('0.3.3');
 
 sub base { return shift->{'base'}; }
 
@@ -18,24 +18,24 @@ sub new {
     my $class = ref $self || $self;
     $self = bless \%args, $class;
 
-    delete $self->{$_} for grep !/base/, keys %$self;
-    $self->$_ for keys %$self;
+    delete $self->{$_} for grep { !/base/xms } keys %{$self};
+    $self->$_ for keys %{$self};
 
     return $self;
 }
 
-sub query { shift->base->call( 'fql.query', @_ ) }
+sub query { return shift->base->call( 'fql.query', @_ ) }
 
 1;    # Magic true value required at end of module
 __END__
 
 =head1 NAME
 
-WWW::Facebook::API::FQL - Message methods for Client
+WWW::Facebook::API::FQL - Facebook Query Language
 
 =head1 VERSION
 
-This document describes WWW::Facebook::API::FQL version 0.3.2
+This document describes WWW::Facebook::API::FQL version 0.3.3
 
 =head1 SYNOPSIS
 
@@ -49,30 +49,36 @@ Methods for accessing messages with L<WWW::Facebook::API>
 
 =over
 
-=item new
+=item new()
 
 Returns a new instance of this class.
 
-=item base
+=back
 
-The L<WWW::Facebook::API::Base> object to use to make calls to
-the REST server.
+=head1 METHODS
 
-=item query
+=over
 
-The fql.query method of the Facebook API.
+=item base()
+
+The L<WWW::Facebook::API> object to use to make calls to the REST server.
+
+=item query( query => 'FQL QUERY LANGUAGE' )
+
+The fql.query method of the Facebook API:
+
+    $response = $client->fql->query( query => 'FQL query' );
 
 =back
 
 =head1 DIAGNOSTICS
 
-This module is used by L<WWW::Facebook::API> and right now does
-not have any unique error messages.
+None.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
-WWW::Facebook::API::FQL requires no configuration files or
-environment variables.
+WWW::Facebook::API::FQL requires no configuration files or environment
+variables.
 
 =head1 DEPENDENCIES
 
