@@ -1,6 +1,6 @@
 #######################################################################
-# $Date: 2007-06-03 21:39:50 -0700 (Sun, 03 Jun 2007) $
-# $Revision: 92 $
+# $Date: 2007-06-07 22:28:00 -0700 (Thu, 07 Jun 2007) $
+# $Revision: 101 $
 # $Author: david.romano $
 # ex: set ts=8 sw=4 et
 #########################################################################
@@ -10,7 +10,7 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.3.2');
+use version; our $VERSION = qv('0.3.3');
 
 sub base { return shift->{'base'}; }
 
@@ -19,26 +19,26 @@ sub new {
     my $class = ref $self || $self;
     $self = bless \%args, $class;
 
-    delete $self->{$_} for grep !/base/, keys %$self;
-    $self->$_ for keys %$self;
+    delete $self->{$_} for grep { !/base/xms } keys %{$self};
+    $self->$_ for keys %{$self};
 
     return $self;
 }
 
-sub get           { shift->base->call( 'friends.get',         @_ ) }
-sub get_app_users { shift->base->call( 'friends.getAppUsers', @_ ) }
-sub are_friends   { shift->base->call( 'friends.areFriends',  @_ ) }
+sub get           { return shift->base->call( 'friends.get',         @_ ) }
+sub get_app_users { return shift->base->call( 'friends.getAppUsers', @_ ) }
+sub are_friends   { return shift->base->call( 'friends.areFriends',  @_ ) }
 
 1;    # Magic true value required at end of module
 __END__
 
 =head1 NAME
 
-WWW::Facebook::API::Friends - Friend methods for Client
+WWW::Facebook::API::Friends - Facebook Friends
 
 =head1 VERSION
 
-This document describes WWW::Facebook::API::Friends version 0.3.2
+This document describes WWW::Facebook::API::Friends version 0.3.3
 
 =head1 SYNOPSIS
 
@@ -52,27 +52,41 @@ Methods for accessing friends with L<WWW::Facebook::API>
 
 =over
 
-=item new
+=item new()
 
 Returns a new instance of this class.
 
-=item base
+=back
 
-The L<WWW::Facebook::API::Base> object to use to make calls to
-the REST server.
+=head1 METHODS
 
-=item get
+=over
 
-The friends.get method of the Facebook API.
+=item base()
 
-=item get_app_users
+The L<WWW::Facebook::API> object to use to make calls to the REST server.
 
-The friends.getAppUsers method of the Facebook API.
+=item get()
 
-=item are_friends
+The friends.get method of the Facebook API:
+
+    $response = $client->friends->get;
+
+=item get_app_users()
+
+The friends.getAppUsers method of the Facebook API:
+
+    $response = $client->friends->get_app_users;
+
+=item are_friends( uids1 => [ ... ], uids2 => [ ... ] )
 
 The friends.areFriends method of the Facebook API. The two arguments are array
-refs that make up an associative array. See the API for further details.
+refs that make up an associative array:
+
+    $response
+        = $client->friends->are_friends( uids1 => [1,7,8], uids2 => [2,3,4] );
+
+See the Facebook API Documentation for more information.
 
 =back
 
@@ -82,8 +96,8 @@ None.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
-WWW::Facebook::API::Friends requires no configuration files or
-environment variables.
+WWW::Facebook::API::Friends requires no configuration files or environment
+variables.
 
 =head1 DEPENDENCIES
 
